@@ -22,16 +22,10 @@ import aiojobs
 import backoff
 import msgspec
 from aiofreqlimit import FreqLimit
-from aiohttp import (
-    BaseConnector,
-    ClientError,
-    ClientSession,
-    FormData,
-    TCPConnector,
-)
+from aiohttp import ClientError, ClientSession, FormData, TCPConnector
 
 from .api_methods import ApiMethods, ParamType
-from .api_types import APIResponse, LocalFile, StreamFile, Update, User
+from .api_types import APIResponse, InputFile, Update, User
 from .bot_update import BotUpdate, Context
 from .constants import ChatType, RequestMethod
 from .exceptions import (
@@ -43,16 +37,16 @@ from .exceptions import (
     RetryAfter,
     TelegramError,
 )
-from .helpers import BotKey, KeyLock, get_software, json_dumps
+from .helpers import BotKey, KeyLock, get_software
 from .storage import StorageProtocol
 
 __all__ = (
     "Bot",
-    "PollBot",
-    "HandlerCallable",
-    "Handler",
-    "HandlerTableProtocol",
     "FilterProtocol",
+    "Handler",
+    "HandlerCallable",
+    "HandlerTableProtocol",
+    "PollBot",
 )
 
 SOFTWARE: Final[str] = get_software()
@@ -70,8 +64,8 @@ response_logger: Final[logging.Logger] = logging.getLogger("aiotgbot.response")
 
 EventHandler = Callable[["Bot"], Awaitable[None]]
 
-_T = TypeVar("_T")
 T = TypeVar("T")
+V = TypeVar("V")
 
 
 class Bot(MutableMapping[str | BotKey[Any], Any], ApiMethods):
@@ -80,32 +74,29 @@ class Bot(MutableMapping[str | BotKey[Any], Any], ApiMethods):
         token: str,
         handler_table: "HandlerTableProtocol",
         storage: StorageProtocol,
-        connector: BaseConnector | None = None,
-        client_trust_env: bool = False,
+        client_session: ClientSession | None = None,
     ) -> None:
         if not handler_table.frozen:
             raise RuntimeError("Can't use unfrozen handler table")
         if not isinstance(handler_table, HandlerTableProtocol):
             raise RuntimeError(
-                "Handler table is not HandlerTableProtocol " "instance"
+                "Handler table is not HandlerTableProtocol instance"
             )
         if not isinstance(storage, StorageProtocol):
             raise RuntimeError(
-                "Storage parameter is not StorageProtocol " "instance"
+                "Storage parameter is not StorageProtocol instance"
             )
         self._token: Final[str] = token
         self._handler_table: Final["HandlerTableProtocol"] = handler_table
         self._storage: Final[StorageProtocol] = storage
-        if connector is not None:
-            _connector: BaseConnector = connector
+        if client_session is not None:
+            client_session.headers.setdefault("User-Agent", SOFTWARE)
         else:
-            _connector = TCPConnector(keepalive_timeout=60)
-        self._client: Final[ClientSession] = ClientSession(
-            connector=_connector,
-            json_serialize=json_dumps,
-            headers={"User-Agent": SOFTWARE},
-            trust_env=client_trust_env,
-        )
+            client_session = ClientSession(
+                connector=TCPConnector(keepalive_timeout=60),
+                headers={"User-Agent": SOFTWARE},
+            )
+        self._client_session: Final[ClientSession] = client_session
         self._context_lock: Final[KeyLock] = KeyLock()
         self._message_limit: Final[FreqLimit] = FreqLimit(MESSAGE_INTERVAL)
         self._chat_limit: Final[FreqLimit] = FreqLimit(CHAT_INTERVAL)
@@ -118,28 +109,28 @@ class Bot(MutableMapping[str | BotKey[Any], Any], ApiMethods):
         self._data: Final[dict[BotKey[Any] | str, object]] = {}
 
     @overload  # type: ignore[override]
-    def __getitem__(self, key: BotKey[_T]) -> _T:
+    def __getitem__(self, key: BotKey[T]) -> T:
         ...
 
     @overload
     def __getitem__(self, key: str) -> Any:
         ...
 
-    def __getitem__(self, key: str | BotKey[_T]) -> Any:
+    def __getitem__(self, key: str | BotKey[T]) -> Any:
         return self._data[key]
 
     @overload  # type: ignore[override]
-    def __setitem__(self, key: BotKey[_T], value: _T) -> None:
+    def __setitem__(self, key: BotKey[T], value: T) -> None:
         ...
 
     @overload
     def __setitem__(self, key: str, value: Any) -> None:
         ...
 
-    def __setitem__(self, key: str | BotKey[_T], value: Any) -> None:
+    def __setitem__(self, key: str | BotKey[T], value: Any) -> None:
         self._data[key] = value
 
-    def __delitem__(self, key: str | BotKey[_T]) -> None:
+    def __delitem__(self, key: str | BotKey[T]) -> None:
         del self._data[key]
 
     def __len__(self) -> int:
@@ -158,10 +149,10 @@ class Bot(MutableMapping[str | BotKey[Any], Any], ApiMethods):
 
     @property
     def client(self) -> ClientSession:
-        if self._client is None:
+        if self._client_session is None:
             raise RuntimeError("Access to client during bot is not running.")
         else:
-            return self._client
+            return self._client_session
 
     def file_url(self, path: str) -> str:
         return TG_FILE_URL.format(token=self._token, path=path)
@@ -175,7 +166,7 @@ class Bot(MutableMapping[str | BotKey[Any], Any], ApiMethods):
         )
 
     @staticmethod
-    def _telegram_exception(api_response: APIResponse[T]) -> TelegramError:
+    def _telegram_exception(api_response: APIResponse) -> TelegramError:
         assert api_response.error_code is not None
         assert api_response.description is not None
         error_code = api_response.error_code
@@ -215,15 +206,20 @@ class Bot(MutableMapping[str | BotKey[Any], Any], ApiMethods):
         self,
         http_method: RequestMethod,
         api_method: str,
-        type_: Type[T],
+        type_: Type[V],
         **params: ParamType,
-    ) -> T:
+    ) -> V:
         data = {
             name: str(value) if isinstance(value, (int, float)) else value
             for name, value in params.items()
             if value is not None
         }
-        bot_logger.debug("Request %s %s %r", http_method, api_method, data)
+        bot_logger.debug(
+            "Request %s %s %r",
+            http_method,
+            api_method,
+            data,
+        )
         if http_method == RequestMethod.GET:
             if len(data) > 0:
                 assert all(isinstance(value, str) for value in data.values())
@@ -233,7 +229,7 @@ class Bot(MutableMapping[str | BotKey[Any], Any], ApiMethods):
         else:
             form_data = FormData()
             for name, value in data.items():
-                if isinstance(value, (StreamFile, LocalFile)):
+                if isinstance(value, InputFile):
                     form_data.add_field(
                         name,
                         value.content,
@@ -246,13 +242,13 @@ class Bot(MutableMapping[str | BotKey[Any], Any], ApiMethods):
 
         url = TG_API_URL.format(token=self._token, method=api_method)
         async with request(url) as response:
-            response_dict = await response.read()
-        decode_type = APIResponse[type_]  # type: ignore
-        api_response = msgspec.json.decode(response_dict, type=decode_type)
-
+            response_data = await response.read()
+        api_response = msgspec.json.decode(response_data, type=APIResponse)
         if api_response.ok:
-            return api_response.result
+            assert isinstance(api_response.result, msgspec.Raw)
+            return msgspec.json.decode(api_response.result, type=type_)
         else:
+            assert api_response.result is msgspec.UNSET
             raise Bot._telegram_exception(api_response)
 
     async def _safe_request(
@@ -260,13 +256,13 @@ class Bot(MutableMapping[str | BotKey[Any], Any], ApiMethods):
         http_method: RequestMethod,
         api_method: str,
         chat_id: int | str,
-        type_: Type[T],
+        type_: Type[V],
         **params: ParamType,
-    ) -> T:
+    ) -> V:
         retry_allowed = all(
-            not isinstance(param, StreamFile) for param in params.values()
+            not isinstance(param, InputFile) for param in params.values()
         )
-        request: Callable[[], Awaitable[T]] = partial(
+        request: Callable[[], Awaitable[V]] = partial(
             self._request,
             http_method,
             api_method,
@@ -292,7 +288,7 @@ class Bot(MutableMapping[str | BotKey[Any], Any], ApiMethods):
                     await asyncio.sleep(retry_after.retry_after)
                 else:
                     bot_logger.error(
-                        "RetryAfter error during " "retry not allowed"
+                        "RetryAfter error during retry not allowed",
                     )
                     raise
 
@@ -357,7 +353,10 @@ class Bot(MutableMapping[str | BotKey[Any], Any], ApiMethods):
     async def _handle_update(self, update: Update) -> None:
         assert self._handler_table.frozen
         assert self._context_lock is not None, "Context lock not initialized"
-        bot_logger.debug('Dispatch update "%s"', update.update_id)
+        bot_logger.debug(
+            'Dispatch update "%s"',
+            update.update_id,
+        )
         update_state = self._update_state(update)
         state_key = f"{STATE_PREFIX}|{update_state}"
         context_key = f"{CONTEXT_PREFIX}|{update_state}"
@@ -381,7 +380,8 @@ class Bot(MutableMapping[str | BotKey[Any], Any], ApiMethods):
                     context_key, bot_update.context.to_dict()
                 )
                 bot_logger.debug(
-                    'Set context for update "%s"', update.update_id
+                    'Set context for update "%s"',
+                    update.update_id,
                 )
             else:
                 bot_logger.debug(
@@ -398,10 +398,10 @@ class Bot(MutableMapping[str | BotKey[Any], Any], ApiMethods):
         )
 
     async def _cleanup(self) -> None:
-        assert self._client is not None
+        assert self._client_session is not None
         assert self._scheduler is not None
         await self._scheduler.close()
-        await self._client.close()
+        await self._client_session.close()
         await self._message_limit.clear()
         await self._chat_limit.clear()
         await self._group_limit.clear()
@@ -421,15 +421,13 @@ class PollBot(Bot):
         token: str,
         handler_table: "HandlerTableProtocol",
         storage: StorageProtocol,
-        connector: BaseConnector | None = None,
-        client_trust_env: bool = False,
+        client_session: ClientSession | None = None,
     ) -> None:
         super().__init__(
             token,
             handler_table,
             storage,
-            connector,
-            client_trust_env,
+            client_session,
         )
         self._poll_task: asyncio.Task[None] | None = None
 
@@ -440,7 +438,9 @@ class PollBot(Bot):
         assert self._me is not None
         self._poll_task = asyncio.create_task(self._poll_wrapper())
         bot_logger.info(
-            "Bot %s (%s) start polling", self._me.first_name, self._me.username
+            "Bot %s (%s) start polling",
+            self._me.first_name,
+            self._me.username,
         )
 
     async def stop(self) -> None:
@@ -462,11 +462,14 @@ class PollBot(Bot):
             pass
         except Exception as exception:
             bot_logger.exception(
-                "Error while polling updates", exc_info=exception
+                "Error while polling updates",
+                exc_info=exception,
             )
         await self._cleanup()
         bot_logger.info(
-            "Bot %s (%s) stop polling", self._me.first_name, self._me.username
+            "Bot %s (%s) stop polling",
+            self._me.first_name,
+            self._me.username,
         )
 
     @backoff.on_exception(backoff.expo, TelegramError)
@@ -475,7 +478,8 @@ class PollBot(Bot):
         bot_logger.debug("Get updates from: %s", self._updates_offset)
         while not self._stopped:
             updates = await self.get_updates(
-                offset=self._updates_offset, timeout=TG_GET_UPDATES_TIMEOUT
+                offset=self._updates_offset,
+                timeout=TG_GET_UPDATES_TIMEOUT,
             )
             for update in updates:
                 await self._scheduler.spawn(
@@ -507,6 +511,7 @@ class HandlerTableProtocol(Protocol):
         ...
 
     @property
+    @abstractmethod
     def frozen(self) -> bool:
         ...
 
