@@ -1,21 +1,19 @@
-from enum import StrEnum, unique
+from enum import IntEnum, StrEnum, unique
 
 __all__ = (
-    "RequestMethod",
-    "ChatType",
     "ChatAction",
     "ChatMemberStatus",
-    "MessageEntityType",
-    "UpdateType",
+    "ChatType",
     "ContentType",
+    "DiceEmoji",
+    "IconColor",
+    "MessageEntityType",
     "ParseMode",
     "PollType",
-    "DiceEmoji",
-    "InputMediaType",
-    "InlineQueryResultType",
-    "PassportElementType",
+    "RequestMethod",
     "StickerFormat",
     "StickerType",
+    "UpdateType",
 )
 
 
@@ -149,49 +147,6 @@ class DiceEmoji(StrEnum):
     BOWLING = "🎳"
 
 
-@unique
-class InputMediaType(StrEnum):
-    PHOTO = "photo"
-    VIDEO = "video"
-    ANIMATION = "animation"
-    AUDIO = "audio"
-    DOCUMENT = "document"
-
-
-@unique
-class InlineQueryResultType(StrEnum):
-    ARTICLE = "article"
-    PHOTO = "photo"
-    GIF = "gif"
-    MPEG4_GIF = "mpeg4_gif"
-    VIDEO = "video"
-    AUDIO = "audio"
-    VOICE = "voice"
-    DOCUMENT = "document"
-    LOCATION = "location"
-    VENUE = "venue"
-    CONTACT = "contact"
-    GAME = "game"
-    STICKER = "sticker"
-
-
-@unique
-class PassportElementType(StrEnum):
-    PERSONAL_DETAILS = "personal_details"
-    PASSPORT = "passport"
-    DRIVER_LICENSE = "driver_license"
-    IDENTITY_CARD = "identity_card"
-    INTERNAL_PASSPORT = "internal_passport"
-    ADDRESS = "address"
-    UTILITY_BILL = "utility_bill"
-    BANK_STATEMENT = "bank_statement"
-    RENTAL_AGREEMENT = "rental_agreement"
-    PASSPORT_REGISTRATION = "passport_registration"
-    TEMPORARY_REGISTRATION = "temporary_registration"
-    PHONE_NUMBER = "phone_number"
-    EMAIL = "email"
-
-
 @unique
 class StickerFormat(StrEnum):
     STATIC = "static"
@@ -204,3 +159,19 @@ class StickerType(StrEnum):
     REGULAR = "regular"
     MASK = "mask"
     CUSTOM_EMOJI = "custom_emoji"
+
+
+class MaskPositionPoint(StrEnum):
+    FOREHEAD = "forehead"
+    EYES = "eyes"
+    MOUTH = "mouth"
+    CHIN = "chin"
+
+
+class IconColor(IntEnum):
+    IC_0x6FB9F0 = 0x6FB9F0
+    IC_0xFFD67E = 0xFFD67E
+    IC_0xCB86DB = 0xCB86DB
+    IC_0x8EEE98 = 0x8EEE98
+    IC_0xFF93B2 = 0xFF93B2
+    IC_0xFB6F5F = 0xFB6F5F
